@@ -1,6 +1,6 @@
 # vim:cindent:ts=2:sw=2:et:fdm=marker:cms=\ #\ %s
 #
-# $Id: Dwww.pm 143 2008-04-27 08:07:20Z robert $
+# $Id: Dwww.pm 151 2008-05-22 12:46:05Z robert $
 #
 
 package Debian::DocBase::Programs::Dwww;
@@ -15,6 +15,7 @@ use vars qw(@ISA @EXPORT);
 
 use Debian::DocBase::Common;
 use Debian::DocBase::Utils;
+use Debian::DocBase::Gettext;
 
 our $dwww_build_menu = "/usr/sbin/dwww-build-menu";
 
@@ -23,14 +24,14 @@ sub RegisterDwww($@) { # {{{
   my $showinfo = shift;
   my @documents = @_;
 
-  Debug("RegisterDwww started");
+  Debug(_g("%s started"), "RegisterDwww");
 
   if (-x $dwww_build_menu) {
-    Inform("Registering documents with dwww...") if $showinfo and $opt_update_menus;
+    Inform(_g("Registering documents with %s..."), "dwww") if $showinfo and $opt_update_menus;
     Execute($dwww_build_menu) if $opt_update_menus;
   } else {
-    Debug("Skipping execution of $dwww_build_menu - dwww package doesn't seem to be installed");
+    Debug(_g("Skipping execution of %s - %s package doesn't seem to be installed"), $dwww_build_menu, "dwww");
   }
-  Debug("RegisterDwww finished");
+  Debug(_g("%s finished"), "RegisterDwww");
 
 } # }}}
